@@ -214,6 +214,13 @@ def get_args():
                             type=int,
                             help='Number of getjob requests')
 
+    arg_parser.add_argument('-x',
+                            dest='getjob_failures',
+                            default=5,
+                            required=False,
+                            type=int,
+                            help='Maximum number of getjob request failures in Harvester mode')
+
     # SSL certificates
     arg_parser.add_argument('--cacert',
                             dest='cacert',
@@ -310,6 +317,15 @@ def get_args():
                             type=str2bool,
                             default=True,
                             help='Cleanup work directory after pilot has finished')
+    arg_parser.add_argument('--use-realtime-logging',
+                            dest='use_realtime_logging',
+                            type=str2bool,
+                            default=False,
+                            help='Use near real-time logging')
+    arg_parser.add_argument('--realtime-logging-server',
+                            dest='realtime_logging_server',
+                            default='',
+                            help='Near real-time logging server')
 
     # Harvester and Nordugrid specific options
     arg_parser.add_argument('--input-dir',
