@@ -10,6 +10,9 @@
 
 import os
 import logging
+from pilot.info import infosys
+import subprocess
+import re
 
 try:
     from google.cloud import storage
@@ -54,6 +57,13 @@ def resolve_surl(fspec, protocol, ddmconf, **kwargs):
         :return: dictionary {'surl': surl}
     """
 
+    try:
+        pandaqueue = infosys.pandaqueue
+    except Exception:
+        pandaqueue = ""
+    if pandaqueue is None:
+        pandaqueue = ""
+
     ddm = ddmconf.get(fspec.ddmendpoint)
     if not ddm:
         raise PilotException('failed to resolve ddmendpoint by name=%s' % fspec.ddmendpoint)
@@ -64,19 +74,7 @@ def resolve_surl(fspec, protocol, ddmconf, **kwargs):
     else:
         dataset = ""
 
-    remote_path = os.path.join(protocol.get('path', ''), dataset)
-
-    # pilot ID is passed by the envvar GTAG
-    # try:
-    #   rprotocols = ddm.rprotocols
-    #   logger.debug('ddm.rprotocols=%s' % rprotocols)
-    #   if "http_access" in rprotocols:
-    #      http_access = rprotocols["http_access"]
-    #      os.environ['GTAG'] = http_access + os.path.join(remote_path, config.Pilot.pilotlog)
-    #      logger.debug('http_access=%s' % http_access)
-    # except Exception:
-    #   logger.warning("Failed in get 'http_access' in ddm.rprotocols")
-
+    remote_path = os.path.join(protocol.get('path', ''), pandaqueue, dataset)
     surl = protocol.get('endpoint', '') + remote_path
     logger.info('For GCS bucket, set surl=%s', surl)
 
@@ -150,23 +148,45 @@ def copy_out(files, **kwargs):
 
     workdir = kwargs.pop('workdir')
 
-    for fspec in files:
-        logger.info('Going to process fspec.turl=%s', fspec.turl)
-
-        import re
+    if len(files) > 0:
+        fspec = files[0]
         # bucket = re.sub(r'gs://(.*?)/.*', r'\1', fspec.turl)
         reobj = re.match(r'gs://([^/]*)/(.*)', fspec.turl)
         (bucket, remote_path) = reobj.groups()
 
-        # ["pilotlog.txt", "payload.stdout", "payload.stderr"]:
-        for logfile in os.listdir(workdir):
-            if logfile.endswith("gz"):
-                continue
+    for fspec in files:
+        logger.info('Going to process fspec.turl=%s', fspec.turl)
+
+        logfiles = []
+        lfn = fspec.lfn.strip(' ')
+        dataset = fspec.dataset
+        if lfn == '/' or dataset.endswith('/'):
+            # ["pilotlog.txt", "payload.stdout", "payload.stderr"]:
+            logfiles = os.listdir(workdir)
+        else:
+            logfiles = [lfn]
+
+        for logfile in logfiles:
             path = os.path.join(workdir, logfile)
             if os.path.exists(path):
+                if logfile == config.Pilot.pilotlog or logfile == config.Payload.payloadstdout or logfile == config.Payload.payloadstderr:
+                    content_type = "text/plain"
+                    logger.info('Change the file=%s content-type to text/plain', logfile)
+                else:
+                    content_type = None
+                    try:
+                        result = subprocess.check_output(["/bin/file", "-i", "-b", "-L", path])
+                        if not isinstance(result, str):
+                            result = result.decode('utf-8')
+                        if result.find(';') > 0:
+                            content_type = result.split(';')[0]
+                            logger.info('Change the file=%s content-type to %s', logfile, content_type)
+                    except Exception:
+                        pass
+
                 object_name = os.path.join(remote_path, logfile)
                 logger.info('uploading %s to bucket=%s using object name=%s', path, bucket, object_name)
-                status, diagnostics = upload_file(path, bucket, object_name=object_name)
+                status, diagnostics = upload_file(path, bucket, object_name=object_name, content_type=content_type)
 
                 if not status:  ## an error occurred
                     # create new error code(s) in ErrorCodes.py and set it/them in resolve_common_transfer_errors()
@@ -181,13 +201,13 @@ def copy_out(files, **kwargs):
                 fspec.status_code = errors.STAGEOUTFAILED
                 raise PilotException(diagnostics, code=fspec.status_code, state=fspec.status)
 
-            fspec.status = 'transferred'
-            fspec.status_code = 0
+        fspec.status = 'transferred'
+        fspec.status_code = 0
 
     return files
 
 
-def upload_file(file_name, bucket, object_name=None):
+def upload_file(file_name, bucket, object_name=None, content_type=None):
     """
     Upload a file to a GCS bucket.
 
@@ -205,9 +225,11 @@ def upload_file(file_name, bucket, object_name=None):
     try:
         client = storage.Client()
         gs_bucket = client.get_bucket(bucket)
-        logger.info('uploading a file to bucket=%s in full path=%s', bucket, object_name)
+        # remove any leading slash(es) in object_name
+        object_name = object_name.lstrip('/')
+        logger.info('uploading a file to bucket=%s in full path=%s in content_type=%s', bucket, object_name, content_type)
         blob = gs_bucket.blob(object_name)
-        blob.upload_from_filename(filename=file_name)
+        blob.upload_from_filename(filename=file_name, content_type=content_type)
         if file_name.endswith(config.Pilot.pilotlog):
             url_pilotlog = blob.public_url
             os.environ['GTAG'] = url_pilotlog
