@@ -109,7 +109,7 @@ def update_job_data(job):
     pass
 
 
-def remove_redundant_files(workdir, outputfiles=[], islooping=False):
+def remove_redundant_files(workdir, outputfiles=[], islooping=False, debugmode=False):
     """
     Remove redundant files and directories prior to creating the log file.
 
@@ -284,3 +284,13 @@ def process_debug_command(debug_command, pandaid):
     """
 
     return debug_command
+
+
+def allow_timefloor(submitmode):
+    """
+    Should the timefloor mechanism (multi-jobs) be allowed for the given submit mode?
+
+    :param submitmode: submit mode (string).
+    """
+
+    return True
